@@ -143,7 +143,7 @@ client_main(
     if (transfer_encoding != NULL)
     {
         headers[header_cnt].name = "Transfer-Encoding";
-        headers[header_cnt].name = transfer_encoding;
+        headers[header_cnt].value = transfer_encoding;
 
         header_cnt++;
 
